==> onlyone-8.x-1.0.tar.gz: onlyone/src/Form/OnlyOneAdminSettings.php <==
<?php

namespace Drupal\onlyone\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Only One module settings.
 */
class OnlyOneAdminSettings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'onlyone_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['onlyone.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $available_content_types = _onlyone_available_content_types(TRUE);
    $not_available_content_types = _onlyone_not_available_content_types(TRUE);

    if (count($available_content_types)) {
      // The details form element with the available content types.
      $form['available_content_type'] = [
        '#type' => 'details',
        '#title' => t('Available content types to have Only One node'),
        '#open' => TRUE,
      ];
      // All the available content types.
      $form['available_content_type']['onlyone_node_types'] = [
        '#type' => 'checkboxes',
        '#title' => t('Configure these content types to allow for the creation of Only One node per language'),
        '#options' => $available_content_types,
        '#default_value' => $this->config('onlyone.settings')->get('onlyone_node_types'),
        '#description' => t('The selected content types will allow Only One node per language.'),
      ];
    }
    // If all the content types are available we don't need to show the element.
    if (count($not_available_content_types)) {
      $collapsed = count($available_content_types) ? FALSE : TRUE;
      // The details form element with the unavailable content types.
      $form['not_available_content_type'] = [
        '#type' => 'details',
        '#title' => t('Not available content types to have Only One node'),
        '#description' => t('The following content types have more than one node in at least one language:'),
        '#open' => $collapsed,
      ];
      // Showing all the not availables content types.
      foreach ($not_available_content_types as $key => $value) {
        $form['not_available_content_type'][$key] = [
          '#type' => 'item',
          '#markup' => $value,
        ];
      }
    }
    // Show the submit button if there is availables content types.
    if (count($available_content_types)) {
      return parent::buildForm($form, $form_state);
    }
    else {
      $form = parent::buildForm($form, $form_state);
      unset($form['actions']);
      return $form;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Saving the configuration.
    $this->config('onlyone.settings')
      ->set('onlyone_node_types', $form_state->getValue('onlyone_node_types'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}

==> onlyone-8.x-1.1.tar.gz: onlyone/src/Form/OnlyOneAdminSettings.php <==
<?php

namespace Drupal\onlyone\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class OnlyOneAdminSettings.
 *
 * @package Drupal\onlyone\Form
 */
class OnlyOneAdminSettings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'onlyone_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['onlyone.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $available_content_types = _onlyone_available_content_types(TRUE);
    $not_available_content_types = _onlyone_not_available_content_types(TRUE);

    if (count($available_content_types)) {
      // The details form element with the available content types.
      $form['available_content_type'] = [
        '#type' => 'details',
        '#title' => t('Available content types to have Only One node'),
        '#open' => TRUE,
      ];
      // All the available content types.
      $form['available_content_type']['onlyone_node_types'] = [
        '#type' => 'checkboxes',
        '#title' => t('Configure these content types to allow for the creation of Only One node per language'),
        '#options' => $available_content_types,
        '#default_value' => $this->config('onlyone.settings')->get('onlyone_node_types'),
        '#description' => t('The selected content types will allow Only One node per language.'),
      ];
    }
    // If all the content types are available we don't need to show the element.
    if (count($not_available_content_types)) {
      $collapsed = count($available_content_types) ? FALSE : TRUE;
      // The details form element with the unavailable content types.
      $form['not_available_content_type'] = [
        '#type' => 'details',
        '#title' => t('Not available content types to have Only One node'),
        '#description' => t('The following content types have more than one node in at least one language:'),
        '#open' => $collapsed,
      ];
      // Showing all the not availables content types.
      foreach ($not_available_content_types as $key => $value) {
        $form['not_available_content_type'][$key] = [
          '#type' => 'item',
          '#markup' => $value,
        ];
      }
    }
    // Show the submit button if there is availables content types.
    if (count($available_content_types)) {
      return parent::buildForm($form, $form_state);
    }
    else {
      $form = parent::buildForm($form, $form_state);
      unset($form['actions']);
      return $form;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Cleaning the array.
    $onlyone_content_types = [];
    foreach ($form_state->getValue('onlyone_node_types') as $content_type) {
      if ($content_type != '0') {
        $onlyone_content_types[] = $content_type;
      }
    }

    // Saving the configuration.
    $this->config('onlyone.settings')
      ->set('onlyone_node_types', $onlyone_content_types)
      ->save();
    // Calling parent method.
    parent::submitForm($form, $form_state);
  }

}
